@@ -1,8 +1,8 @@
-from concurrent.futures import ThreadPoolExecutor
-
 from bs4 import BeautifulSoup
+from concurrent.futures import ThreadPoolExecutor
 from requests import get
 from string_utils.validation import is_integer
+from dept_scraper import dept_authors
 
 import utils
 from utils.config import get_config
@@ -64,3 +64,16 @@ def parse(soup):
         })
 
     return result
+
+
+def dept_scholar_docs(dept_id, affil_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
+                      min_year=None, max_year=None, max_workers=None):
+    authors = dept_authors(dept_id, affil_id)
+    output = []
+
+    for author in authors:
+        author['docs'] = author_scholar_docs(author['id'], min_year, max_year, max_workers)
+
+        output.append(author)
+
+    return utils.format_output(output, output_format, pretty_print, xml_library)
